@@ -2,10 +2,10 @@ snr_rms <- function(int, baseline, gauge) {
   SNR <- 0
   int <- sort(int - baseline)
   Signal <- max(int)
-  xN <- which(int/Signal < (1-gauge))
+  xN <- which(int/Signal < (1 - gauge))
   NVec <- int[xN]
   Noise <- sqrt(sum(NVec^2)/length(NVec)) # root mean square
-  if (is.na(Noise) == FALSE) {
+  if (is.numeric(Noise)) {
     if (Noise != 0) {
       SNR <- Signal/Noise
     } else {
@@ -13,4 +13,4 @@ snr_rms <- function(int, baseline, gauge) {
     }
   }
   return(SNR)
-}
\ No newline at end of file
+}
